@@ -5,8 +5,8 @@ import os
 import sys
 import yaml
 
-import must_triage.formatters as formatters
-import must_triage.inspectors as inspectors
+from must_triage import formatters
+from must_triage import inspectors
 
 
 def parse_args(args):
@@ -31,7 +31,10 @@ def main():
     for inspector_cls in inspectors.all():
         inspector = inspector_cls(root=args.path, progress=not args.quiet)
         inspector.gather()
-        inspectors.merge_interests(interests, asyncio.run(inspector.inspect()))
+        inspectors.util.merge_interests(
+            interests,
+            asyncio.run(inspector.inspect())
+        )
 
     if args.out == 'json':
         print(json.dumps(
